@@ -23,18 +23,19 @@
 #
 #  For all license terms see README.md and LICENSE Files in root directory of this Project.
 
-from icinga2confgen.Checks.Icinga2Confgen.CheckExistingUsers import CheckExistingUsers
-from icinga2confgen.Checks.Icinga2Confgen.CheckGroupMembers import CheckGroupMembers
-from icinga2confgen.Checks.Icinga2Confgen.CheckSSHDSecurity import CheckSSHDSecurity
-from icinga2confgen.Checks.Icinga2Confgen.CheckUFWStatus import CheckUFWStatus
-from icinga2confgen.Checks.MonitoringPlugins.CheckApt import CheckApt
-from icinga2confgen.Checks.MonitoringPlugins.CheckDisk import CheckDisk
-from icinga2confgen.Checks.MonitoringPlugins.CheckLoad import CheckLoad
-from icinga2confgen.Checks.MonitoringPlugins.CheckNTPTime import CheckNTPTime
-from icinga2confgen.Checks.MonitoringPlugins.CheckProcs import CheckProcs
-from icinga2confgen.Checks.MonitoringPlugins.CheckSWAP import CheckSWAP
-from icinga2confgen.Checks.MonitoringPlugins.CheckUsers import CheckUsers
-from icinga2confgen.Checks.NagiosPlugins.CheckYum import CheckYum
+from icinga2confgen.Checks.HariSekhonNagiosPlugins.CheckYum import CheckYum
+from icinga2confgen.Checks.MonitoringPlugins.CheckExistingUsers import CheckExistingUsers
+from icinga2confgen.Checks.MonitoringPlugins.CheckGroupMembers import CheckGroupMembers
+from icinga2confgen.Checks.MonitoringPlugins.CheckSSHDSecurity import CheckSSHDSecurity
+from icinga2confgen.Checks.MonitoringPlugins.CheckUFWStatus import CheckUFWStatus
+from icinga2confgen.Checks.NagiosPlugins.CheckApt import CheckApt
+from icinga2confgen.Checks.NagiosPlugins.CheckDisk import CheckDisk
+from icinga2confgen.Checks.NagiosPlugins.CheckLoad import CheckLoad
+from icinga2confgen.Checks.NagiosPlugins.CheckNTPTime import CheckNTPTime
+from icinga2confgen.Checks.NagiosPlugins.CheckProcs import CheckProcs
+from icinga2confgen.Checks.NagiosPlugins.CheckSWAP import CheckSWAP
+from icinga2confgen.Checks.NagiosPlugins.CheckUsers import CheckUsers
+from icinga2confgen.Dependency.CheckDependency import CheckDependency
 from icinga2confgen.Groups.ServiceGroup import ServiceGroup
 from icinga2confgen.ValueChecker import ValueChecker
 
@@ -431,14 +432,21 @@ class DefaultLocalChecks:
                 self.apply_notification_to_check(check)
                 server.add_check(check)
 
+            sshd_running_check = None
+            if True is self.__check_sshd_running:
+                sshd_running_check = self.create_running_check('sshd', 'sshd', server)
+
             if True is self.__check_sshd_security:
                 check = CheckSSHDSecurity.create('sshd_security_' + server.get_id()) \
                     .set_check_type(self.__check_type)
                 self.apply_notification_to_check(check)
                 server.add_check(check)
 
-            if True is self.__check_sshd_running:
-                self.create_running_check('sshd', 'sshd', server)
+                if None != sshd_running_check:
+                    dependency = CheckDependency.create('sshd_security_require_sshd_running_' + server.get_id()) \
+                        .set_server(server) \
+                        .set_check(sshd_running_check)
+                    check.add_dependency(dependency)
 
             if True is self.__check_mysqld_running:
                 check = self.create_running_check('mysql', 'mysqld', server)
